Release history
===============

.. currentmodule:: aioserf

.. towncrier release notes start

AioSerf 0.2.0 (2018-12-18)
--------------------------

Features
~~~~~~~~

- :mod:`aioserf` now supports 100% of Serf's RPC interface.
- Documentation (using sphinx)!

